@@ -1,12 +1,12 @@
 package Sah::Schema::Rinci;
 
+our $DATE = '2014-10-30'; # DATE
+our $VERSION = '1.1.67'; # VERSION
+
 use 5.010001;
 use strict;
 use warnings;
 
-our $VERSION = '1.1.66'; # VERSION
-our $DATE = '2014-10-29'; # DATE
-
 our %SCHEMAS;
 
 my %dh_props = (
@@ -64,6 +64,7 @@ $SCHEMAS{rinci_function} = [hash => {
                 pos => {},
                 greedy => {},
                 partial => {},
+                stream => {},
                 is_password => {},
                 cmdline_aliases => {
                     _value_prop => {
@@ -148,7 +149,25 @@ $SCHEMAS{rinci_function}[1]{_prop}{args}{_value_prop}{element_meta} =
 
 # rinci_package
 # rinci_variable
-# rinci_result
+
+$SCHEMAS{rinci_resmeta} = [hash => {
+    # tmp
+    _ver => 1.1,
+    _prop => {
+        %dh_props,
+
+        perm_err => {},
+        func => {}, # XXX func.*
+        cmdline => {}, # XXX cmdline.*
+        logs => {},
+        prev => {},
+        results => {},
+        part_start => {},
+        part_len => {},
+        len => {},
+        stream => {},
+    },
+}];
 
 # list of known special arguments: -dry_run, -action, -tx_action,
 # -res_part_start, -res_part_len, -arg_part_start, -arg_part_len
@@ -168,7 +187,7 @@ Sah::Schema::Rinci - Sah schemas for Rinci metadata
 
 =head1 VERSION
 
-This document describes version 1.1.66 of Sah::Schema::Rinci (from Perl distribution Rinci), released on 2014-10-29.
+This document describes version 1.1.67 of Sah::Schema::Rinci (from Perl distribution Rinci), released on 2014-10-30.
 
 =head1 HOMEPAGE
 
